@@ -25,12 +25,11 @@
 #define LISTS_H
 
 #include <QString>
-#include <klocale.h>
-#include <kglobal.h>
+#include <QLocale>
 
 static inline QString getMailingList()
 {
-    QString lang(KGlobal::locale()->language());
+    QString lang(QLocale::system().name());
     if(lang.startsWith("ca"))
         return "kde-i18n-ca@kde.org";
     if(lang.startsWith("de"))
@@ -45,6 +44,8 @@ static inline QString getMailingList()
         return "kde-i18n-lt@kde.org";
     if(lang.startsWith("nb"))
         return "i18n-nb@lister.ping.uio.no";
+    if(lang.startsWith("nl"))
+        return "kde-i18n-nl@kde.org";
     if(lang.startsWith("nn"))
         return "i18n-nn@lister.ping.uio.no";
     if(lang.startsWith("pt_BR"))
